@@ -1,6 +1,8 @@
 package main
 
 import (
+	"unicode"
+
 	"github.com/gdamore/tcell/v2"
 	"github.com/rivo/tview"
 
@@ -13,13 +15,21 @@ type ProjectDetailPane struct {
 	project *model.Project
 }
 
+func removeProjectWithConfirmation() {
+	AskYesNo("Do you want to delete Project?", projectPane.RemoveActivateProject)
+}
+
+func clearCompletedWithConfirmation() {
+	AskYesNo("Do you want to clear completed tasks?", taskPane.ClearCompletedTasks)
+}
+
 // NewProjectDetailPane Initializes ProjectDetailPane
 func NewProjectDetailPane() *ProjectDetailPane {
 	pane := ProjectDetailPane{
 		Flex: tview.NewFlex().SetDirection(tview.FlexRow),
 	}
-	deleteBtn := makeButton("[::u]D[::-]elete Project", projectPane.RemoveActivateProject)
-	clearBtn := makeButton("[::u]C[::-]lear Completed Tasks", taskPane.ClearCompletedTasks)
+	deleteBtn := makeButton("[::u]D[::-]elete Project", removeProjectWithConfirmation)
+	clearBtn := makeButton("[::u]C[::-]lear Completed Tasks", clearCompletedWithConfirmation)
 
 	deleteBtn.SetBackgroundColor(tcell.ColorRed)
 	pane.
@@ -44,12 +54,12 @@ func (pd *ProjectDetailPane) isShowing() bool {
 }
 
 func (pd *ProjectDetailPane) handleShortcuts(event *tcell.EventKey) *tcell.EventKey {
-	switch event.Rune() {
+	switch unicode.ToLower(event.Rune()) {
 	case 'd':
-		projectPane.RemoveActivateProject()
+		removeProjectWithConfirmation()
 		return nil
 	case 'c':
-		taskPane.ClearCompletedTasks()
+		clearCompletedWithConfirmation()
 		return nil
 	}
 
